NAME
Parrot::OpTrans::CPrederef - C Predereferenced Transform
DESCRIPTION
Parrot::OpTrans::CPrederef inherits from Parrot::OpTrans::C to provide basic functionality for predereferenced run loops (switch, CGP).
Instance Methods
defines()-
Returns the C
#definemacros required by the ops. - expr_address($addr)
- expr_address($offset)
- expr_pop()
-
Create various address parts.
access_arg($type, $num, $op)-
Returns the C code for the specified op argument type (see
Parrot::OpTrans) and value.$opis an instance ofParrot::Op.